==> ikaaro-0.50.0.tar.gz: ikaaro-0.50.0/ui/tiny_mce/langs/ja.js <==
tinyMCE.addI18n({ja:{
common:{
edit_confirm:"WYSIWYG\u30E2\u30FC\u30C9\u306B\u5207\u308A\u66FF\u3048\u307E\u3059\u304B\uFF1F",
apply:"\u9069\u7528",
insert:"\u633F\u5165",
update:"\u66F4\u65B0",
cancel:"\u30AD\u30E3\u30F3\u30BB\u30EB",
close:"\u9589\u3058\u308B",
browse:"\u53C2\u7167",
class_name:"\u30AF\u30E9\u30B9",
not_set:"-- \u672A\u8A2D\u5B9A --",
clipboard_msg:"\u30B3\u30D4\u30FC/\u5207\u308A\u53D6\u308A/\u8CBC\u308A\u4ED8\u3051\u306FMozilla\u53CA\u3073Firefox\u3067\u306F\u4F7F\u7528\u3067\u304D\u307E\u305B\u3093\u3002\n\u8A73\u7D30\u306F\u3053\u3061\u3089",
clipboard_no_support:"\u30AF\u30EA\u30C3\u30D7\u30DC\u30FC\u30C9\u64CD\u4F5C\u306F\u304A\u4F7F\u3044\u306E\u30D6\u30E9\u30A6\u30B6\u306B\u306F\u5BFE\u5FDC\u3057\u3066\u304A\u308A\u307E\u305B\u3093\u3002\u4EE3\u308F\u308A\u306B\u30AD\u30FC\u30DC\u30FC\u30C9\u306E\u30B7\u30E7\u30FC\u30C8\u30AB\u30C3\u30C8\u30AD\u30FC\u3092\u304A\u4F7F\u3044\u4E0B\u3055\u3044\u3002",
popup_blocked:"\u30DD\u30C3\u30D7\u30A2\u30C3\u30D7\u304C\u30D6\u30ED\u30C3\u30AF\u3055\u308C\u307E\u3057\u305F\u3002\u3059\u3079\u3066\u306E\u6A5F\u80FD\u3092\u3054\u5229\u7528\u306B\u306A\u308B\u306B\u306F\u30DD\u30C3\u30D7\u30A2\u30C3\u30D7\u3092\u8A31\u53EF\u3057\u3066\u4E0B\u3055\u3044\u3002",
invalid_data:"\u30A8\u30E9\u30FC: \u5165\u529B\u306B\u8AA4\u308A\u304C\u3042\u308A\u307E\u3059\u3002\uFF08\u8D64\u5B57\u306E\u9805\u76EE\uFF09",
more_colors:"\u305D\u306E\u4ED6\u306E\u8272"
},
contextmenu:{
align:"\u914D\u7F6E",
left:"\u5DE6\u63C3\u3048",
center:"\u4E2D\u592E\u63C3\u3048",
right:"\u53F3\u63C3\u3048",
full:"\u5747\u7B49\u5272\u4ED8"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"\u65E5\u4ED8\u306E\u633F\u5165",
inserttime_desc:"\u6642\u523B\u306E\u633F\u5165",
months_long:"January,February,March,April,May,June,July,August,September,October,November,December",
months_short:"Jan,Feb,Mar,Apr,May,Jun,Jul,Aug,Sep,Oct,Nov,Dec",
day_long:"\u65E5\u66DC\u65E5,\u6708\u66DC\u65E5,\u706B\u66DC\u65E5,\u6C34\u66DC\u65E5,\u6728\u66DC\u65E5,\u91D1\u66DC\u65E5,\u571F\u66DC\u65E5,\u65E5\u66DC\u65E5",
day_short:"(\u65E5),(\u6708),(\u706B),(\u6C34),(\u6728),(\u91D1),(\u571F),(\u65E5)"
},
print:{
print_desc:"\u5370\u5237"
},
preview:{
preview_desc:"\u30D7\u30EC\u30D3\u30E5\u30FC"
},
directionality:{
ltr_desc:"\u5DE6\u304B\u3089\u53F3",
rtl_desc:"\u53F3\u304B\u3089\u5DE6"
},
layer:{
insertlayer_desc:"\u65B0\u898F\u30EC\u30A4\u30E4\u30FC\u306E\u633F\u5165",
forward_desc:"\u524D\u9762\u3078\u79FB\u52D5",
backward_desc:"\u80CC\u9762\u3078\u79FB\u52D5",
absolute_desc:"\u7D76\u5BFE\u4F4D\u7F6E\u6307\u5B9A\u306E\u5207\u66FF",
content:"\u65B0\u898F\u30EC\u30A4\u30E4\u30FC"
},
save:{
save_desc:"\u4FDD\u5B58",
cancel_desc:"\u5168\u3066\u306E\u5909\u66F4\u3092\u7834\u68C4"
},
nonbreaking:{
nonbreaking_desc:"\u6539\u884C\u306A\u3057\u30B9\u30DA\u30FC\u30B9\u306E\u633F\u5165"
},
iespell:{
iespell_desc:"\u30B9\u30DA\u30EB\u30C1\u30A7\u30C3\u30AF",
download:"ieSpell\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093\u3002\u4ECA\u3059\u3050\u30A4\u30F3\u30B9\u30C8\u30FC\u30EB\u3057\u307E\u3059\u304B\uFF1F"
},
advhr:{
advhr_desc:"\u6C34\u5E73\u7DDA"
},
emotions:{
emotions_desc:"\u8868\u60C5\u30A2\u30A4\u30B3\u30F3"
},
searchreplace:{
search_desc:"\u691C\u7D22",
replace_desc:"\u691C\u7D22/\u7F6E\u63DB"
},
advimage:{
image_desc:"\u753B\u50CF\u306E\u633F\u5165/\u7DE8\u96C6"
},
advlink:{
link_desc:"\u30EA\u30F3\u30AF\u306E\u633F\u5165/\u7DE8\u96C6"
},
xhtmlxtras:{
cite_desc:"\u5F15\u7528",
abbr_desc:"\u7565\u8A9E",
acronym_desc:"\u982D\u5B57\u8A9E",
del_desc:"\u524A\u9664",
ins_desc:"\u633F\u5165",
attribs_desc:"\u5C5E\u6027\u306E\u633F\u5165/\u7DE8\u96C6"
},
style:{
desc:"CSS\u7DE8\u96C6"
},
paste:{
paste_text_desc:"\u30C6\u30AD\u30B9\u30C8\u3068\u3057\u3066\u8CBC\u308A\u4ED8\u3051",
paste_word_desc:"Word\u304B\u3089\u8CBC\u308A\u4ED8\u3051",
selectall_desc:"\u5168\u3066\u9078\u629E"
},
paste_dlg:{
text_title:"\u30AD\u30FC\u30DC\u30FC\u30C9\u3067CTRL+V\u3068\u5165\u529B\u3057\u30C6\u30AD\u30B9\u30C8\u3092\u8CBC\u308A\u4ED8\u3051\u3066\u304F\u3060\u3055\u3044\u3002",
text_linebreaks:"\u6539\u884C\u3092\u4FDD\u6301\u3059\u308B",
word_title:"\u30AD\u30FC\u30DC\u30FC\u30C9\u3067CTRL+V\u3068\u5165\u529B\u3057\u30C6\u30AD\u30B9\u30C8\u3092\u8CBC\u308A\u4ED8\u3051\u3066\u304F\u3060\u3055\u3044\u3002"
},
table:{
desc:"\u8868\u3092\u633F\u5165",
row_before_desc:"\u884C\u3092\u4E0A\u306B\u633F\u5165",
row_after_desc:"\u884C\u3092\u4E0B\u306B\u633F\u5165",
delete_row_desc:"\u884C\u3092\u524A\u9664",
col_before_desc:"\u5217\u3092\u5DE6\u306B\u633F\u5165",
col_after_desc:"\u5217\u3092\u53F3\u306B\u633F\u5165",
delete_col_desc:"\u5217\u3092\u524A\u9664",
split_cells_desc:"\u30BB\u30EB\u306E\u7D50\u5408\u3092\u89E3\u9664",
merge_cells_desc:"\u30BB\u30EB\u3092\u7D50\u5408",
row_desc:"\u884C\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
cell_desc:"\u30BB\u30EB\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
props_desc:"\u8868\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
paste_row_before_desc:"\u884C\u3092\u4E0A\u306B\u8CBC\u308A\u4ED8\u3051",
paste_row_after_desc:"\u884C\u3092\u4E0B\u306B\u8CBC\u308A\u4ED8\u3051",
cut_row_desc:"\u884C\u306E\u5207\u308A\u53D6\u308A",
copy_row_desc:"\u884C\u306E\u30B3\u30D4\u30FC",
del:"\u8868\u3092\u524A\u9664",
row:"\u884C",
col:"\u5217",
cell:"\u30BB\u30EB"
},
autosave:{
unload_msg:"\u4ED6\u306E\u30DA\u30FC\u30B8\u3078\u79FB\u52D5\u3059\u308B\u3068\u7DE8\u96C6\u30C7\u30FC\u30BF\u306F\u3059\u3079\u3066\u7834\u68C4\u3055\u308C\u307E\u3059\u3002"
},
fullscreen:{
desc:"\u30D5\u30EB\u30B9\u30AF\u30EA\u30FC\u30F3"
},
media:{
desc:"\u57CB\u3081\u8FBC\u307F\u30E1\u30C7\u30A3\u30A2\u306E\u633F\u5165/\u7DE8\u96C6",
edit:"\u57CB\u3081\u8FBC\u307F\u30E1\u30C7\u30A3\u30A2\u306E\u7DE8\u96C6"
},
fullpage:{
desc:"\u30DA\u30FC\u30B8\u8A2D\u5B9A"
},
template:{
desc:"\u30C6\u30F3\u30D7\u30EC\u30FC\u30C8\u306E\u633F\u5165"
},
visualchars:{
desc:"\u5236\u5FA1\u6587\u5B57\u306E\u8868\u793A"
},
spellchecker:{
desc:"\u30B9\u30DA\u30EB\u30C1\u30A7\u30C3\u30AFOn/Off",
menu:"\u30B9\u30DA\u30EB\u30C1\u30A7\u30C3\u30AF\u8A2D\u5B9A",
ignore_word:"\u3053\u306E\u5358\u8A9E\u3092\u7121\u8996",
ignore_words:"\u5168\u3066\u7121\u8996",
langs:"\u8A00\u8A9E",
wait:"\u3057\u3070\u3089\u304F\u304A\u5F85\u3061\u304F\u3060\u3055\u3044...",
sug:"\u5019\u88DC",
no_sug:"\u5019\u88DC\u306F\u6709\u308A\u307E\u305B\u3093\u3002",
no_mpell:"\u30B9\u30DA\u30EB\u30DF\u30B9\u306F\u898B\u3064\u304B\u308A\u307E\u305B\u3093\u3067\u3057\u305F\u3002"
},
pagebreak:{
desc:"\u6539\u30DA\u30FC\u30B8\u633F\u5165"
}}});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/langs/ja.js <==
tinyMCE.addI18n({ja:{
common:{
edit_confirm:"WYSIWYG\u30E2\u30FC\u30C9\u306B\u5207\u308A\u66FF\u3048\u307E\u3059\u304B\uFF1F",
apply:"\u9069\u7528",
insert:"\u633F\u5165",
update:"\u66F4\u65B0",
cancel:"\u30AD\u30E3\u30F3\u30BB\u30EB",
close:"\u9589\u3058\u308B",
browse:"\u53C2\u7167",
class_name:"class\u5C5E\u6027",
not_set:"-- \u672A\u8A2D\u5B9A --",
clipboard_msg:"\u3053\u306E\u30B3\u30DE\u30F3\u30C9\u306FFirefox\u3067\u306F\u4F7F\u7528\u3067\u304D\u307E\u305B\u3093\u3002",
clipboard_no_support:"\u30AF\u30EA\u30C3\u30D7\u30DC\u30FC\u30C9\u64CD\u4F5C\u306F\u304A\u4F7F\u3044\u306E\u30D6\u30E9\u30A6\u30B6\u306B\u306F\u5BFE\u5FDC\u3057\u3066\u304A\u308A\u307E\u305B\u3093\u3002\u4EE3\u308F\u308A\u306B\u30AD\u30FC\u30DC\u30FC\u30C9\u306E\u30B7\u30E7\u30FC\u30C8\u30AB\u30C3\u30C8\u30AD\u30FC\u3092\u304A\u4F7F\u3044\u4E0B\u3055\u3044\u3002",
popup_blocked:"\u30DD\u30C3\u30D7\u30A2\u30C3\u30D7\u304C\u30D6\u30ED\u30C3\u30AF\u3055\u308C\u307E\u3057\u305F\u3002\u3059\u3079\u3066\u306E\u6A5F\u80FD\u3092\u3054\u5229\u7528\u306B\u306A\u308B\u306B\u306F\u30DD\u30C3\u30D7\u30A2\u30C3\u30D7\u3092\u8A31\u53EF\u3057\u3066\u4E0B\u3055\u3044\u3002",
invalid_data:"\u30A8\u30E9\u30FC: \u5165\u529B\u306B\u8AA4\u308A\u304C\u3042\u308A\u307E\u3059\u3002\uFF08\u8D64\u5B57\u306E\u9805\u76EE\uFF09",
more_colors:"\u305D\u306E\u4ED6\u306E\u8272"
},
contextmenu:{
align:"\u914D\u7F6E",
left:"\u5DE6\u63C3\u3048",
center:"\u4E2D\u592E\u63C3\u3048",
right:"\u53F3\u63C3\u3048",
full:"\u5747\u7B49\u5272\u4ED8"
},
insertdatetime:{
date_fmt:"%Y-%m-%d",
time_fmt:"%H:%M:%S",
insertdate_desc:"\u65E5\u4ED8\u306E\u633F\u5165",
inserttime_desc:"\u6642\u523B\u306E\u633F\u5165",
months_long:"January,February,March,April,May,June,July,August,September,October,November,December",
months_short:"Jan,Feb,Mar,Apr,May,Jun,Jul,Aug,Sep,Oct,Nov,Dec",
day_long:"\u65E5\u66DC\u65E5,\u6708\u66DC\u65E5,\u706B\u66DC\u65E5,\u6C34\u66DC\u65E5,\u6728\u66DC\u65E5,\u91D1\u66DC\u65E5,\u571F\u66DC\u65E5,\u65E5\u66DC\u65E5",
day_short:"(\u65E5),(\u6708),(\u706B),(\u6C34),(\u6728),(\u91D1),(\u571F),(\u65E5)"
},
print:{
print_desc:"\u5370\u5237"
},
preview:{
preview_desc:"\u30D7\u30EC\u30D3\u30E5\u30FC"
},
directionality:{
ltr_desc:"\u5DE6\u304B\u3089\u53F3",
rtl_desc:"\u53F3\u304B\u3089\u5DE6"
},
layer:{
insertlayer_desc:"\u65B0\u898F\u30EC\u30A4\u30E4\u30FC\u306E\u633F\u5165",
forward_desc:"\u524D\u9762\u3078\u79FB\u52D5",
backward_desc:"\u80CC\u9762\u3078\u79FB\u52D5",
absolute_desc:"\u7D76\u5BFE\u4F4D\u7F6E\u6307\u5B9A\u306E\u5207\u66FF",
content:"\u65B0\u898F\u30EC\u30A4\u30E4\u30FC"
},
save:{
save_desc:"\u4FDD\u5B58",
cancel_desc:"\u5168\u3066\u306E\u5909\u66F4\u3092\u7834\u68C4"
},
nonbreaking:{
nonbreaking_desc:"\u6539\u884C\u306A\u3057\u30B9\u30DA\u30FC\u30B9\u306E\u633F\u5165"
},
iespell:{
iespell_desc:"\u30B9\u30DA\u30EB\u30C1\u30A7\u30C3\u30AF",
download:"ieSpell\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093\u3002\u4ECA\u3059\u3050\u30A4\u30F3\u30B9\u30C8\u30FC\u30EB\u3057\u307E\u3059\u304B\uFF1F"
},
advhr:{
advhr_desc:"\u6C34\u5E73\u7DDA"
},
emotions:{
emotions_desc:"\u8868\u60C5\u30A2\u30A4\u30B3\u30F3"
},
searchreplace:{
search_desc:"\u691C\u7D22",
replace_desc:"\u691C\u7D22/\u7F6E\u63DB"
},
advimage:{
image_desc:"\u753B\u50CF\u306E\u633F\u5165/\u7DE8\u96C6"
},
advlink:{
link_desc:"\u30EA\u30F3\u30AF\u306E\u633F\u5165/\u7DE8\u96C6"
},
xhtmlxtras:{
cite_desc:"\u5F15\u7528",
abbr_desc:"\u7565\u8A9E",
acronym_desc:"\u982D\u5B57\u8A9E",
del_desc:"\u524A\u9664",
ins_desc:"\u633F\u5165",
attribs_desc:"\u5C5E\u6027\u306E\u633F\u5165/\u7DE8\u96C6"
},
style:{
desc:"CSS\u7DE8\u96C6"
},
paste:{
paste_text_desc:"\u30C6\u30AD\u30B9\u30C8\u3068\u3057\u3066\u8CBC\u308A\u4ED8\u3051",
paste_word_desc:"Word\u304B\u3089\u8CBC\u308A\u4ED8\u3051",
selectall_desc:"\u5168\u3066\u9078\u629E",
plaintext_mode_sticky:"Paste is now in plain text mode. Click again to toggle back to regular paste mode. After you paste something you will be returned to regular paste mode.",
plaintext_mode:"\u30D7\u30EC\u30FC\u30F3\u30C6\u30AD\u30B9\u30C8\u30E2\u30FC\u30C9\u306B\u5909\u66F4\u3057\u307E\u3057\u305F\u3002\u8CBC\u308A\u4ED8\u3051\u5F8C\u306F\u66F8\u5F0F\u4ED8\u304D\u30E2\u30FC\u30C9\u306B\u623B\u308A\u307E\u3059\u3002"
},
paste_dlg:{
text_title:"\u30AD\u30FC\u30DC\u30FC\u30C9\u3067CTRL+V\u3092\u62BC\u3057\u3066\u30C6\u30AD\u30B9\u30C8\u3092\u8CBC\u308A\u4ED8\u3051\u3066\u304F\u3060\u3055\u3044\u3002",
text_linebreaks:"\u6539\u884C\u3092\u4FDD\u6301\u3059\u308B",
word_title:"\u30AD\u30FC\u30DC\u30FC\u30C9\u3067CTRL+V\u3092\u62BC\u3057\u3066\u30C6\u30AD\u30B9\u30C8\u3092\u8CBC\u308A\u4ED8\u3051\u3066\u304F\u3060\u3055\u3044\u3002"
},
table:{
desc:"\u8868\u3092\u633F\u5165",
row_before_desc:"\u884C\u3092\u4E0A\u306B\u633F\u5165",
row_after_desc:"\u884C\u3092\u4E0B\u306B\u633F\u5165",
delete_row_desc:"\u884C\u3092\u524A\u9664",
col_before_desc:"\u5217\u3092\u5DE6\u306B\u633F\u5165",
col_after_desc:"\u5217\u3092\u53F3\u306B\u633F\u5165",
delete_col_desc:"\u5217\u3092\u524A\u9664",
split_cells_desc:"\u30BB\u30EB\u306E\u7D50\u5408\u3092\u89E3\u9664",
merge_cells_desc:"\u30BB\u30EB\u3092\u7D50\u5408",
row_desc:"\u884C\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
cell_desc:"\u30BB\u30EB\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
props_desc:"\u8868\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
paste_row_before_desc:"\u884C\u3092\u4E0A\u306B\u8CBC\u308A\u4ED8\u3051",
paste_row_after_desc:"\u884C\u3092\u4E0B\u306B\u8CBC\u308A\u4ED8\u3051",
cut_row_desc:"\u884C\u306E\u5207\u308A\u53D6\u308A",
copy_row_desc:"\u884C\u306E\u30B3\u30D4\u30FC",
del:"\u8868\u3092\u524A\u9664",
row:"\u884C",
col:"\u5217",
cell:"\u30BB\u30EB"
},
autosave:{
unload_msg:"\u4ED6\u306E\u30DA\u30FC\u30B8\u3078\u79FB\u52D5\u3059\u308B\u3068\u7DE8\u96C6\u30C7\u30FC\u30BF\u306F\u3059\u3079\u3066\u7834\u68C4\u3055\u308C\u307E\u3059\u3002",
restore_content:"Restore auto-saved content.",
warning_message:"If you restore the saved content, you will lose all the content that is currently in the editor.\n\nAre you sure you want to restore the saved content?."
},
fullscreen:{
desc:"\u30D5\u30EB\u30B9\u30AF\u30EA\u30FC\u30F3"
},
media:{
desc:"\u57CB\u3081\u8FBC\u307F\u30E1\u30C7\u30A3\u30A2\u306E\u633F\u5165/\u7DE8\u96C6",
edit:"\u57CB\u3081\u8FBC\u307F\u30E1\u30C7\u30A3\u30A2\u306E\u7DE8\u96C6"
},
fullpage:{
desc:"\u30DA\u30FC\u30B8\u8A2D\u5B9A"
},
template:{
desc:"\u30C6\u30F3\u30D7\u30EC\u30FC\u30C8\u306E\u633F\u5165"
},
visualchars:{
desc:"\u5236\u5FA1\u6587\u5B57\u306E\u8868\u793A"
},
spellchecker:{
desc:"\u30B9\u30DA\u30EB\u30C1\u30A7\u30C3\u30AFOn/Off",
menu:"\u30B9\u30DA\u30EB\u30C1\u30A7\u30C3\u30AF\u8A2D\u5B9A",
ignore_word:"\u3053\u306E\u5358\u8A9E\u3092\u7121\u8996",
ignore_words:"\u5168\u3066\u7121\u8996",
langs:"\u8A00\u8A9E",
wait:"\u3057\u3070\u3089\u304F\u304A\u5F85\u3061\u304F\u3060\u3055\u3044...",
sug:"\u5019\u88DC",
no_sug:"\u5019\u88DC\u306F\u6709\u308A\u307E\u305B\u3093\u3002",
no_mpell:"\u30B9\u30DA\u30EB\u30DF\u30B9\u306F\u898B\u3064\u304B\u308A\u307E\u305B\u3093\u3067\u3057\u305F\u3002"
},
pagebreak:{
desc:"\u6539\u30DA\u30FC\u30B8\u633F\u5165"
},
advlist:{
types:"Types",
def:"Default",
lower_alpha:"Lower alpha",
lower_greek:"Lower greek",
lower_roman:"Lower roman",
upper_alpha:"Upper alpha",
upper_roman:"Upper roman",
circle:"Circle",
disc:"Disc",
square:"Square"
}}});
